CBox

Struct CBox 

pub struct CBox<T, TAllocator: Allocator> { /* private fields */ }
The ABI-stable box type. This type is equivalent to the standard Box type, except it is suitable for FFI and also accepts any allocator.

Implementations

Source

impl<T, TAllocator: Allocator> CBox<T, TAllocator>

pub fn new(value: T) -> Result<Self, CBoxError>
where TAllocator: Default,

Creates a new CBox with the default allocator.

Errors

For details see CBoxError.

pub fn with_allocator( value: T, allocator: TAllocator, ) -> Result<Self, CBoxError>

Creates a new CBox with a custom allocator.

Errors

For details see CBoxError.

pub const fn data(box_: &Self) -> &T

Returns a reference to the data stored in the CBox.

pub const fn data_mut(box_: &mut Self) -> &mut T

Returns a mutable reference to the data stored in the CBox.

pub const fn data_ptr(box_: &Self) -> *const T

Returns a raw pointer to the underlying data stored in the CBox.

The caller must ensure that the pointer does not outlive the CBox.

pub const fn into_raw_ptr(box_: Self) -> *mut u8

Converts the CBox into a raw pointer.

Notes
  • This method does not touch internal structure of the CBox, self is simply forgotten.
  • The caller must ensure that the pointer does not outlive the CBox.
pub const unsafe fn from_raw_ptr(ptr: *mut u8) -> Self

Converts a raw pointer back to a CBox container.

Safety
  • The caller must ensure that the pointer came from the previous call to CBox::into_raw_ptr.
  • The caller must ensure that the raw pointer won’t be used after the call.

Otherwise the behavior is undefined.

pub const fn data_ptr_mut(box_: &mut Self) -> *mut T

Returns a raw mutable pointer to the underlying data stored in the CBox.

The caller must ensure that the pointer does not outlive the CBox.

pub fn unpack(box_: Self) -> T

Unpacks the CBox and returns the data. The underlying memory gets deallocated.