pub struct CBox<T, TAllocator: Allocator> { /* private fields */ }Expand description
The ABI-stable box type. This type is equivalent to the standard Box type,
except it is suitable for FFI and also accepts any allocator.
Implementations
Sourceimpl<T, TAllocator: Allocator> CBox<T, TAllocator>
impl<T, TAllocator: Allocator> CBox<T, TAllocator>
Sourcepub fn with_allocator(
value: T,
allocator: TAllocator,
) -> Result<Self, CBoxError>
pub fn with_allocator( value: T, allocator: TAllocator, ) -> Result<Self, CBoxError>
Sourcepub const fn data_mut(box_: &mut Self) -> &mut T
pub const fn data_mut(box_: &mut Self) -> &mut T
Returns a mutable reference to the data stored in the CBox.
Sourcepub const fn into_raw_ptr(box_: Self) -> *mut u8
pub const fn into_raw_ptr(box_: Self) -> *mut u8
Sourcepub const unsafe fn from_raw_ptr(ptr: *mut u8) -> Self
pub const unsafe fn from_raw_ptr(ptr: *mut u8) -> Self
Converts a raw pointer back to a CBox container.
Safety
- The caller must ensure that the pointer came from the previous
call to
CBox::into_raw_ptr. - The caller must ensure that the raw pointer won’t be used after the call.
Otherwise the behavior is undefined.
Sourcepub const fn data_ptr_mut(box_: &mut Self) -> *mut T
pub const fn data_ptr_mut(box_: &mut Self) -> *mut T